==> scalar__code-highlight-0.0.27.jar: META-INF/resources/webjars/scalar__code-highlight/0.0.27/CHANGELOG.md <==
# @scalar/code-highlight

## 0.0.27

### Patch Changes

- 799845f: feat(components): allow ScalarCodeblock to support different font sizes

## 0.0.26

### Patch Changes

- 0e888bc: feat: add dart to standard languages

## 0.0.25

### Patch Changes

- 632978d: fix(themes): hide summary caret in reset

## 0.0.24

### Patch Changes

- 9319c0c: fix: allows alert plugin classes in markdown
- 9319c0c: feat: updates markdown alert style

## 0.0.23

### Patch Changes

- 3feee27: feat: adds markdown alert support
- c10bbf5: chore: code style

## 0.0.22

### Patch Changes

- e350f23: chore: code style

## 0.0.21

### Patch Changes

- fa6afe8: chore: code formatting
- 1223c1f: chore: code style

## 0.0.20

### Patch Changes

- 109e320: fix: removes regex for highlight credentials

## 0.0.19

### Patch Changes

- 6407b2b: feat(api-reference): extend font weights for links and sidebar items

## 0.0.18

### Patch Changes

- e199e9b: feat: updates chevron down icon

## 0.0.17

### Patch Changes

- 9002259: style: font size fixtures

## 0.0.16

### Patch Changes

- 1b06f64: fix(api-reference): conflicting styles with bulma, galaxy bug on docs

## 0.0.15

### Patch Changes

- a40999d: chore: added type safety rule noUncheckedIndexedAccess

## 0.0.14

### Patch Changes

- b4a93ab: fix: tag typography and intro type

## 0.0.13

### Patch Changes

- 0c34a18: chore: updated vue package to 3.5

## 0.0.12

### Patch Changes

- e911047: Add default exports

## 0.0.11

### Patch Changes

- 18744d4: feat(code-highlight): don't force markdown paragraph color

## 0.0.10

### Patch Changes

- c450bb3: fix: scalar api ref use scalar-border-width

## 0.0.9

### Patch Changes

- 58e5912: fix: markdown fixes and intro card polish

## 0.0.8

### Patch Changes

- b910fc1: feat: new Markdown helper methods splitContent and getHeadings

## 0.0.7

### Patch Changes

- c2362ee: fix: don't constrain markdown image height

## 0.0.6

### Patch Changes

- 9b035b0: chore: remove stale packages

## 0.0.5

### Patch Changes

- 94e68ab: chore: upgrade typescript to 5.5

## 0.0.4

### Patch Changes

- 5e92eab: feat(#doc-1996): themes css exports

## 0.0.3

### Patch Changes

- e0fc110: chore: patch bump all package

## 0.0.2

### Patch Changes

- 8494349: Migrate to highlightjs based syntax highlighting
- 6fbb57e: feat: release all the packages

==> scalar__code-highlight-0.1.1.jar: META-INF/resources/webjars/scalar__code-highlight/0.1.1/CHANGELOG.md <==
# @scalar/code-highlight

## 0.1.1

### Patch Changes

- 785939b: feat: adds id to markdown heading
- cad6277: feat(themes)!: migrate to tailwind v4

## 0.1.0

### Minor Changes

- 483ca93: chore: require Node 20 (or above)

## 0.0.29

### Patch Changes

- 8c7bad8: chore: move build tooling to esbuild

## 0.0.28

### Patch Changes

- e8457cb: Unify themes across scalar. Cleanup interface and remove CJS build.

## 0.0.27

### Patch Changes

- 799845f: feat(components): allow ScalarCodeblock to support different font sizes

## 0.0.26

### Patch Changes

- 0e888bc: feat: add dart to standard languages

## 0.0.25

### Patch Changes

- 632978d: fix(themes): hide summary caret in reset

## 0.0.24

### Patch Changes

- 9319c0c: fix: allows alert plugin classes in markdown
- 9319c0c: feat: updates markdown alert style

## 0.0.23

### Patch Changes

- 3feee27: feat: adds markdown alert support
- c10bbf5: chore: code style

## 0.0.22

### Patch Changes

- e350f23: chore: code style

## 0.0.21

### Patch Changes

- fa6afe8: chore: code formatting
- 1223c1f: chore: code style

## 0.0.20

### Patch Changes

- 109e320: fix: removes regex for highlight credentials

## 0.0.19

### Patch Changes

- 6407b2b: feat(api-reference): extend font weights for links and sidebar items

## 0.0.18

### Patch Changes

- e199e9b: feat: updates chevron down icon

## 0.0.17

### Patch Changes

- 9002259: style: font size fixtures

## 0.0.16

### Patch Changes

- 1b06f64: fix(api-reference): conflicting styles with bulma, galaxy bug on docs

## 0.0.15

### Patch Changes

- a40999d: chore: added type safety rule noUncheckedIndexedAccess

## 0.0.14

### Patch Changes

- b4a93ab: fix: tag typography and intro type

## 0.0.13

### Patch Changes

- 0c34a18: chore: updated vue package to 3.5

## 0.0.12

### Patch Changes

- e911047: Add default exports

## 0.0.11

### Patch Changes

- 18744d4: feat(code-highlight): don't force markdown paragraph color

## 0.0.10

### Patch Changes

- c450bb3: fix: scalar api ref use scalar-border-width

## 0.0.9

### Patch Changes

- 58e5912: fix: markdown fixes and intro card polish

## 0.0.8

### Patch Changes

- b910fc1: feat: new Markdown helper methods splitContent and getHeadings

## 0.0.7

### Patch Changes

- c2362ee: fix: don't constrain markdown image height

## 0.0.6

### Patch Changes

- 9b035b0: chore: remove stale packages

## 0.0.5

### Patch Changes

- 94e68ab: chore: upgrade typescript to 5.5

## 0.0.4

### Patch Changes

- 5e92eab: feat(#doc-1996): themes css exports

## 0.0.3

### Patch Changes

- e0fc110: chore: patch bump all package

## 0.0.2

### Patch Changes

- 8494349: Migrate to highlightjs based syntax highlighting
- 6fbb57e: feat: release all the packages
